Index: uspace/drv/vhc/conndev.c
===================================================================
--- uspace/drv/vhc/conndev.c	(revision 17aca1c1f6f00b4b526e475b7eead4405501c16b)
+++ uspace/drv/vhc/conndev.c	(revision ca56afa3b0b0f909bd3118c008bb162cd5f45a0d)
@@ -76,9 +76,9 @@
 /** Default handler for IPC methods not handled by DDF.
  *
  * @param dev Device handling the call.
  * @param icallid Call id.
  * @param icall Call data.
  */
-void default_connection_handler(device_t *dev,
+void default_connection_handler(ddf_fun_t *fun,
     ipc_callid_t icallid, ipc_call_t *icall)
 {
@@ -112,5 +112,5 @@
  * @param d Device the client was connected to.
  */
-void on_client_close(device_t *d)
+void on_client_close(ddf_fun_t *fun)
 {
 	/*
@@ -76,9 +76,9 @@
 /** Default handler for IPC methods not handled by DDF.
  *
- * @param dev Device handling the call.
+ * @param fun Device handling the call.
  * @param icallid Call id.
  * @param icall Call data.
